@@ -1,19 +1,12 @@
 #============================================================================================================
 #
-#	bbs.cgixW[(VARDA)
-#	varda.pl
-#	---------------------------------------------
-#	2003.02.06 start
-#	2004.03.31 eύX
-#
-#	낿˂vX
-#	2010.08.12 VXeςɔύX
+#	bbs.cgixW[
 #
 #============================================================================================================
 package	VARDA;
 
 use strict;
-use warnings;
+#use warnings;
 
 #------------------------------------------------------------------------------------------------------------
 #
@@ -25,18 +18,17 @@ use warnings;
 #------------------------------------------------------------------------------------------------------------
 sub new
 {
-	my $this = shift;
-	my $obj = {};
+	my $class = shift;
 	
-	$obj = {
+	my $obj = {
 		'SYS'		=> undef,
 		'SET'		=> undef,
 		'THREADS'	=> undef,
 		'CONV'		=> undef,
 		'BANNER'	=> undef,
-		'CODE'		=> undef
+		'CODE'		=> undef,
 	};
-	bless $obj, $this;
+	bless $obj, $class;
 	
 	return $obj;
 }
@@ -60,13 +52,13 @@ sub Init
 	require './module/denethor.pl';
 	
 	# gpW[ݒ
-	$this->{'SYS'}		= $Sys;
-	$this->{'THREADS'}	= BILBO->new;
-	$this->{'CONV'}		= GALADRIEL->new;
-	$this->{'BANNER'}	= DENETHOR->new;
-	$this->{'CODE'}		= 'sjis';
+	$this->{'SYS'} = $Sys;
+	$this->{'THREADS'} = BILBO->new;
+	$this->{'CONV'} = GALADRIEL->new;
+	$this->{'BANNER'} = DENETHOR->new;
+	$this->{'CODE'} = 'sjis';
 	
-	if (! defined $Setting) {
+	if (!defined $Setting) {
 		require './module/isildur.pl';
 		$this->{'SET'} = ISILDUR->new;
 		$this->{'SET'}->Load($Sys);
@@ -91,12 +83,10 @@ sub Init
 sub CreateIndex
 {
 	my $this = shift;
-	my ($Sys, $Threads, $bbsSetting, $Index, $Caption);
-	my ($path, $i);
 	
-	$Sys		= $this->{'SYS'};
-	$Threads 	= $this->{'THREADS'};
-	$bbsSetting	= $this->{'SET'};
+	my $Sys = $this->{'SYS'};
+	my $Threads = $this->{'THREADS'};
+	my $bbsSetting = $this->{'SET'};
 	
 	# CREATE[hA܂̓Xbhindex\͈͓̏ꍇ̂indexXV
 	if ($Sys->Equal('MODE', 'CREATE')
@@ -104,15 +94,15 @@ sub CreateIndex
 		
 		require './module/thorin.pl';
 		require './module/legolas.pl';
-		$Index = THORIN->new;
-		$Caption = LEGOLAS->new;
+		my $Index = THORIN->new;
+		my $Caption = LEGOLAS->new;
 		
 		PrintIndexHead($this, $Index, $Caption);
 		PrintIndexMenu($this, $Index);
 		PrintIndexPreview($this, $Index);
 		PrintIndexFoot($this, $Index, $Caption);
 		
-		$path = $Sys->Get('BBSPATH') . '/' . $Sys->Get('BBS') . '/index.html';
+		my $path = $Sys->Get('BBSPATH') . '/' . $Sys->Get('BBS') . '/index.html';
 		$Index->Flush(1, $Sys->Get('PM-TXT'), $path);
 		
 		return 1;
@@ -131,61 +121,50 @@ sub CreateIndex
 sub CreateIIndex
 {
 	my $this = shift;
-	my ($Sys, $Threads, $bbsSetting, $oConv, $Page);
-	my ($path, $i, $name, $key, $res, $cgiPath, $title, $menuNum, $code, $bbs);
-	my (@threadSet);
 	
 	require './module/thorin.pl';
-	$Page = THORIN->new;
+	my $Page = THORIN->new;
 	
 	# O
-	$Sys		= $this->{'SYS'};
-	$Threads 	= $this->{'THREADS'};
-	$bbsSetting	= $this->{'SET'};
-	$oConv		= $this->{'CONV'};
-	
-	$cgiPath	= $Sys->Get('CGIPATH');
-	$title		= $bbsSetting->Get('BBS_TITLE');
-	$menuNum	= $bbsSetting->Get('BBS_MAX_MENU_THREAD');
-	$code		= $this->{'CODE'};
-	$i			= 1;
-	$bbs		= $Sys->Get('BBS');
-	
-	# SXbh擾
-	$Threads->GetKeySet('ALL', '', \@threadSet);
+	my $Sys = $this->{'SYS'};
+	my $Threads = $this->{'THREADS'};
+	my $Set = $this->{'SET'};
+	my $Conv = $this->{'CONV'};
+	my $bbs = $Sys->Get('BBS');
 	
 	# HTMLwb_̏o
+	my $title = $Set->Get('BBS_TITLE');
+	my $code = $this->{'CODE'};
 	$Page->Print("<html><!--nobanner--><head><title>$title</title>");
 	$Page->Print("<meta http-equiv=Content-Type content=\"text/html;charset=$code\">");
 	$Page->Print("</head><body><center>$title</center>");
 	
 	# oi[\
-	$this->{'BANNER'}->Print($Page, 100, 1, 1);
-	$Page->Print('<hr></center>');
+	$this->{'BANNER'}->Print($Page, 100, 3, 1);
+	
+	# SXbh擾
+	my @threadSet = ();
+	$Threads->GetKeySet('ALL', '', \@threadSet);
 	
 	# Xbh[v܂킷
-	foreach $key (@threadSet) {
-		if ($i > $menuNum) {
-			last;
-		}
-		$name = $Threads->Get('SUBJECT', $key);
-		$res = $Threads->Get('RES', $key);
-		$path = $oConv->CreatePath($Sys, 1, $bbs, $key, 'l10');
+	my $menuNum = $Set->Get('BBS_MAX_MENU_THREAD');
+	my $i = 0;
+	foreach my $key (@threadSet) {
+		last if (++$i > $menuNum);
+		
+		my $name = $Threads->Get('SUBJECT', $key);
+		my $res = $Threads->Get('RES', $key);
+		my $path = $Conv->CreatePath($Sys, 'O', $bbs, $key, 'l10');
 		
 		$Page->Print("<a href=\"$path\">$i: $name($res)</a><br> \n");
-		$i++;
 	}
 	
 	# tb^̏o
-	if ($Sys->Get('PATHKIND')) {
-		$path = "$cgiPath/p.cgi?bbs=$bbs&st=$i";
-	}
-	else {
-		$path = "$cgiPath/p.cgi/$bbs/$i";
-	}
+	my $cgiPath = $Sys->Get('CGIPATH');
+	my $pathf = "$cgiPath/p.cgi" . ($Sys->Get('PATHKIND') ? "?bbs=$bbs&st=$i" : "/$bbs/$i");
 	$Page->Print("<hr>");
-	$Page->Print("<a href=\"$path\"></a>\n");
-	$Page->Print("<form action=\"$cgiPath/bbs.cgi\" method=\"POST\" utn>");
+	$Page->Print("<a href=\"$pathf\"></a>\n");
+	$Page->Print("<form action=\"$cgiPath/bbs.cgi?guid=ON\" method=\"POST\">");
 	$Page->Print("<input type=hidden name=bbs value=$bbs>");
 	$Page->Print("<input type=hidden name=mb value=on>");
 	$Page->Print("<input type=hidden name=thread value=on>");
@@ -193,8 +172,8 @@ sub CreateIIndex
 	$Page->Print("</form><hr></body></html>\n");
 	
 	# i/index.htmlɏ
-	$path = $Sys->Get('BBSPATH') . "/$bbs";
-	$Page->Flush(1, $Sys->Get('PM-TXT'), "$path/i/index.html");
+	my $pathi = $Sys->Get('BBSPATH') . "/$bbs";
+	$Page->Flush(1, $Sys->Get('PM-TXT'), "$pathi/i/index.html");
 }
 
 #------------------------------------------------------------------------------------------------------------
@@ -204,41 +183,26 @@ sub CreateIIndex
 #	@param	Ȃ
 #	@return	Ȃ
 #
-#	2010.08.12 windyakin 
-#	 -> m\CӐݒł悤ɂȂ̂ŕύX
-#
 #------------------------------------------------------------------------------------------------------------
 sub CreateSubback
 {
 	my $this = shift;
-	my ($Sys, $Threads, $bbsSetting, $oConv, $Page);
-	my ($path, $i, $name, $key, $res, $cgipath, $title, $code, $bbs);
-	my (@threadSet, $max, $Caption, $version);
 	
 	require './module/thorin.pl';
-	$Page = THORIN->new;
+	my $Page = THORIN->new;
 	
-	$Sys		= $this->{'SYS'};
-	$Threads 	= $this->{'THREADS'};
-	$bbsSetting	= $this->{'SET'};
-	$oConv		= $this->{'CONV'};
-	
-	$cgipath	= $Sys->Get('CGIPATH');
-	$title		= $bbsSetting->Get('BBS_TITLE');
-	$code		= $this->{'CODE'};
-	$i			= 1;
-	$bbs		= $Sys->Get('BBS');
-	$max		= $Sys->Get('SUBMAX');
-	$version	= $Sys->Get('VERSION');
-	
-	# SXbh擾
-	$Threads->GetKeySet('ALL', '', \@threadSet);
+	my $Sys = $this->{'SYS'};
+	my $Threads = $this->{'THREADS'};
+	my $Set = $this->{'SET'};
+	my $Conv = $this->{'CONV'};
 	
 	require './module/legolas.pl';
-	$Caption = LEGOLAS->new;
+	my $Caption = LEGOLAS->new;
 	$Caption->Load($Sys, 'META');
 	
 	# HTMLwb_̏o
+	my $title = $Set->Get('BBS_TITLE');
+	my $code = $this->{'CODE'};
 	$Page->Print(<<HTML);
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html lang="ja">
@@ -254,25 +218,34 @@ HTML
 	$Page->Print("</head>\n<body>\n\n");
 	
 	# oi[\
-	$this->{'BANNER'}->Print($Page, 100, 2, 0) if ($Sys->Get('BANNER'));
+	if ($Sys->Get('BANNER')) {
+		$this->{'BANNER'}->Print($Page, 100, 2, 0);
+	}
 	
 	$Page->Print("<div class=\"threads\">");
 	$Page->Print("<small>\n");
 	
+	# SXbh擾
+	my @threadSet = ();
+	$Threads->GetKeySet('ALL', '', \@threadSet);
+	
 	# Xbh[v܂킷
-	foreach $key (@threadSet) {
-		if ($i > $max) {
-			last;
-		}
-		$name = $Threads->Get('SUBJECT', $key);
-		$res = $Threads->Get('RES', $key);
-		$path = $oConv->CreatePath($Sys, 0, $bbs, $key, 'l50');
+	my $bbs = $Sys->Get('BBS');
+	my $max = $Sys->Get('SUBMAX');
+	my $i = 0;
+	foreach my $key (@threadSet) {
+		last if (++$i > $max);
+		
+		my $name = $Threads->Get('SUBJECT', $key);
+		my $res = $Threads->Get('RES', $key);
+		my $path = $Conv->CreatePath($Sys, 0, $bbs, $key, 'l50');
 		
 		$Page->Print("<a href=\"$path\" target=\"_blank\">$i: $name($res)</a>&nbsp;&nbsp;\n");
-		$i++;
 	}
 	
 	# tb^̏o
+	my $cgipath = $Sys->Get('CGIPATH');
+	my $version = $Sys->Get('VERSION');
 	$Page->Print(<<HTML);
 </small>
 </div>
@@ -284,7 +257,6 @@ HTML
 <hr>
 
 <div align="right">
-<a href="http://validator.w3.org/check?uri=referer"><img src="$cgipath/datas/html.gif" alt="Valid HTML 4.01 Transitional" height="15" width="80" border="0"></a>
 $version
 </div>
 
@@ -293,8 +265,8 @@ $version
 HTML
 	
 	# subback.htmlɏ
-	$path = $Sys->Get('BBSPATH') . "/$bbs";
-	$Page->Flush(1, $Sys->Get('PM-TXT'), "$path/subback.html");
+	my $paths = $Sys->Get('BBSPATH') . "/$bbs";
+	$Page->Flush(1, $Sys->Get('PM-TXT'), "$paths/subback.html");
 }
 
 #------------------------------------------------------------------------------------------------------------
@@ -308,14 +280,14 @@ HTML
 #------------------------------------------------------------------------------------------------------------
 sub PrintIndexHead
 {
-	my ($this, $Page, $Caption) = @_;
-	my ($title, $link, $image, $code);
+	my $this = shift;
+	my ($Page, $Caption) = @_;
 	
 	$Caption->Load($this->{'SYS'}, 'META');
-	$title	= $this->{'SET'}->Get('BBS_TITLE');
-	$link	= $this->{'SET'}->Get('BBS_TITLE_LINK');
-	$image	= $this->{'SET'}->Get('BBS_TITLE_PICTURE');
-#	$code	= $this->{'CODE'};
+	my $title = $this->{'SET'}->Get('BBS_TITLE');
+	my $link = $this->{'SET'}->Get('BBS_TITLE_LINK');
+	my $image = $this->{'SET'}->Get('BBS_TITLE_PICTURE');
+#	my $code = $this->{'CODE'};
 	
 	# HTMLwb_̏o
 	$Page->Print(<<HEAD);
@@ -341,7 +313,7 @@ HEAD
 	
 	# <body>^Oo
 	{
-		my @work;
+		my @work = ();
 		$work[0] = $this->{'SET'}->Get('BBS_BG_COLOR');
 		$work[1] = $this->{'SET'}->Get('BBS_TEXT_COLOR');
 		$work[2] = $this->{'SET'}->Get('BBS_LINK_COLOR');
@@ -353,18 +325,20 @@ HEAD
 		$Page->Print("alink=\"$work[3]\" vlink=\"$work[4]\" background=\"$work[5]\">\n");
 
 	}
-	$Page->Print("<a name=\"top\"></a>\n<div align=\"center\">");
+	$Page->Print("<a name=\"top\"></a>\n");
 	
 	# Ŕ摜\
 	if ($image ne '') {
+		$Page->Print("<div align=\"center\">");
 		# Ŕ摜̃N
 		if ($link ne '') {
-			$Page->Print("<a href=\"$link\"><img src=\"$image\" border=\"0\" alt=\"$link\"></a></div>\n");
+			$Page->Print("<a href=\"$link\"><img src=\"$image\" border=\"0\" alt=\"$link\"></a>");
 		}
 		# Ŕ摜ɃN͂Ȃ
 		else {
-			$Page->Print("<img src=\"$image\" border=\"0\" alt=\"$link\"></div>\n");
+			$Page->Print("<img src=\"$image\" border=\"0\" alt=\"$link\">");
 		}
+		$Page->Print("</div>\n");
 	}
 	
 	# wb_e[u̕\
@@ -382,18 +356,11 @@ HEAD
 #------------------------------------------------------------------------------------------------------------
 sub PrintIndexMenu
 {
-	my ($this, $Page) = @_;
-	my ($Conv, $menuCol, $menuNum, $prevNum, $i);
-	my (@threadSet, $key, $name, $res, $path, $max);
+	my $this = shift;
+	my ($Page) = @_;
 	
-	$Conv		= $this->{'CONV'};
-	$menuCol	= $this->{'SET'}->Get('BBS_MENU_COLOR');
-	$menuNum	= $this->{'SET'}->Get('BBS_MAX_MENU_THREAD');
-	$prevNum	= $this->{'SET'}->Get('BBS_THREAD_NUMBER');
-	$i			= 1;
-	$max		= $this->{'SYS'}->Get('SUBMAX');
-	
-	$this->{'THREADS'}->GetKeySet('ALL', '', \@threadSet);
+	my $Conv = $this->{'CONV'};
+	my $menuCol = $this->{'SET'}->Get('BBS_MENU_COLOR');
 	
 	# oi[̕\
 	$this->{'BANNER'}->Print($Page, 95, 0, 0);
@@ -407,14 +374,20 @@ sub PrintIndexMenu
   <small>
 MENU
 	
+	my @threadSet = ();
+	$this->{'THREADS'}->GetKeySet('ALL', '', \@threadSet);
+	
 	# Xbh[v܂킷
-	foreach $key (@threadSet) {
-		if (($i > $menuNum) || ($i > $max)) {
-			last;
-		}
-		$name = $this->{'THREADS'}->Get('SUBJECT', $key);
-		$res = $this->{'THREADS'}->Get('RES', $key);
-		$path = $Conv->CreatePath($this->{'SYS'}, 0, $this->{'SYS'}->Get('BBS'), $key, 'l50');
+	my $prevNum = $this->{'SET'}->Get('BBS_THREAD_NUMBER');
+	my $menuNum = $this->{'SET'}->Get('BBS_MAX_MENU_THREAD');
+	my $max = $this->{'SYS'}->Get('SUBMAX');
+	my $i = 0;
+	foreach my $key (@threadSet) {
+		last if ((++$i > $menuNum) || ($i > $max));
+		
+		my $name = $this->{'THREADS'}->Get('SUBJECT', $key);
+		my $res = $this->{'THREADS'}->Get('RES', $key);
+		my $path = $Conv->CreatePath($this->{'SYS'}, 0, $this->{'SYS'}->Get('BBS'), $key, 'l50');
 		
 		# vr[Xbh̏ꍇ̓vr[ւ̃N\
 		if ($i <= $prevNum) {
@@ -424,7 +397,6 @@ MENU
 		else {
 			$Page->Print("  <a href=\"$path\" target=\"body\">$i: $name($res)</a>@\n");
 		}
-		$i++;
 	}
 	$Page->Print(<<MENU);
   </small>
@@ -451,21 +423,20 @@ MENU
 #------------------------------------------------------------------------------------------------------------
 sub PrintIndexPreview
 {
-	my ($this, $Page) = @_;
-	my ($oDat, $oConv, @threadSet, $Plugin);
-	my ($prevNum, $threadNum, $prevT, $nextT, $tblCol, $ttlCol);
-	my ($basePath, $datPath, $cnt, $subject, $res, $key, $max);
+	my $this = shift;
+	my ($Page) = @_;
 	
 	# g@\[h
 	require './module/athelas.pl';
-	$Plugin = ATHELAS->new;
+	my $Plugin = ATHELAS->new;
 	$Plugin->Load($this->{'SYS'});
 	
 	# LȊg@\ꗗ擾
-	my (@pluginSet, @commands, $id, $count);
+	my @commands = ();
+	my @pluginSet = ();
 	$Plugin->GetKeySet('VALID', 1, \@pluginSet);
-	$count = 0;
-	foreach $id (@pluginSet) {
+	my $count = 0;
+	foreach my $id (@pluginSet) {
 		# ^Cvread.cgȉꍇ̓[hĎs
 		if ($Plugin->Get('TYPE', $id) & 8) {
 			my $file = $Plugin->Get('FILE', $id);
@@ -473,36 +444,35 @@ sub PrintIndexPreview
 			if (-e "./plugin/$file") {
 				require "./plugin/$file";
 				my $Config = PLUGINCONF->new($Plugin, $id);
-				$commands[$count] = $className->new($Config);
-				$count++;
+				$commands[$count++] = $className->new($Config);
 			}
 		}
 	}
 	
 	require './module/gondor.pl';
-	$oDat = ARAGORN->new;
+	my $Dat = ARAGORN->new;
 	
+	my @threadSet = ();
 	$this->{'THREADS'}->GetKeySet('ALL', '', \@threadSet);
 	
 	# O
-	$prevNum	= $this->{'SET'}->Get('BBS_THREAD_NUMBER');
-	$threadNum	= (@threadSet > $prevNum ? $prevNum : @threadSet);
-	$tblCol		= $this->{'SET'}->Get('BBS_THREAD_COLOR');
-	$ttlCol		= $this->{'SET'}->Get('BBS_SUBJECT_COLOR');
-	$prevT		= $threadNum;
-	$nextT		= ($threadNum > 1 ? 2 : 1);
-	$oConv		= $this->{'CONV'};
-	$basePath	= $this->{'SYS'}->Get('BBSPATH') . '/' . $this->{'SYS'}->Get('BBS');
-	$cnt		= 1;
-	$max		= $this->{'SYS'}->Get('SUBMAX');
+	my $prevNum = $this->{'SET'}->Get('BBS_THREAD_NUMBER');
+	my $threadNum = (scalar(@threadSet) > $prevNum ? $prevNum : scalar(@threadSet));
+	my $tblCol = $this->{'SET'}->Get('BBS_THREAD_COLOR');
+	my $ttlCol = $this->{'SET'}->Get('BBS_SUBJECT_COLOR');
+	my $prevT = $threadNum;
+	my $nextT = ($threadNum > 1 ? 2 : 1);
+	my $Conv = $this->{'CONV'};
+	my $basePath = $this->{'SYS'}->Get('BBSPATH') . '/' . $this->{'SYS'}->Get('BBS');
+	my $max = $this->{'SYS'}->Get('SUBMAX');
 	
-	foreach $key (@threadSet) {
-		if ($cnt > $prevNum || $cnt > $max) {
-			last;
-		}
-		$subject	= $this->{'THREADS'}->Get('SUBJECT', $key);
-		$res		= $this->{'THREADS'}->Get('RES', $key);
-		$nextT		= 1 if ($cnt == $threadNum);
+	my $cnt = 0;
+	foreach my $key (@threadSet) {
+		last if (++$cnt > $prevNum || $cnt > $max);
+		
+		my $subject = $this->{'THREADS'}->Get('SUBJECT', $key);
+		my $res = $this->{'THREADS'}->Get('RES', $key);
+		$nextT = 1 if ($cnt == $threadNum);
 		
 		# wb_̕\
 		$Page->Print(<<THREAD);
@@ -516,20 +486,17 @@ sub PrintIndexPreview
 THREAD
 		
 		# vr[̕\
-		$datPath = "$basePath/dat/$key.dat";
-		$oDat->Load($this->{'SYS'}, $datPath, 1);
+		my $datPath = "$basePath/dat/$key.dat";
+		$Dat->Load($this->{'SYS'}, $datPath, 1);
 		$this->{'SYS'}->Set('KEY', $key);
-		PrintThreadPreviewOne($this, $Page, $oDat, \@commands);
-		$oDat->Close();
+		PrintThreadPreviewOne($this, $Page, $Dat, \@commands);
+		$Dat->Close();
 		
 		# tb^̕\
-		{
-			my ($allPath, $lastPath, $numPath);
-			
-			$allPath	= $oConv->CreatePath($this->{'SYS'}, 0, $this->{'SYS'}->Get('BBS'), $key, '');
-			$lastPath	= $oConv->CreatePath($this->{'SYS'}, 0, $this->{'SYS'}->Get('BBS'), $key, 'l50');
-			$numPath	= $oConv->CreatePath($this->{'SYS'}, 0, $this->{'SYS'}->Get('BBS'), $key, '1-100');
-			$Page->Print(<<KAKIKO);
+		my $allPath = $Conv->CreatePath($this->{'SYS'}, 0, $this->{'SYS'}->Get('BBS'), $key, '');
+		my $lastPath = $Conv->CreatePath($this->{'SYS'}, 0, $this->{'SYS'}->Get('BBS'), $key, 'l50');
+		my $numPath = $Conv->CreatePath($this->{'SYS'}, 0, $this->{'SYS'}->Get('BBS'), $key, '1-100');
+		$Page->Print(<<KAKIKO);
     <div style="font-weight:bold;">
      <a href="$allPath">Sǂ</a>
      <a href="$lastPath">ŐV50</a>
@@ -545,14 +512,11 @@ THREAD
 </table>
 
 KAKIKO
-			
-		}
 		
 		# JE^̍XV
 		$nextT++;
 		$prevT++;
 		$prevT = 1 if ($cnt == 1);
-		$cnt++;
 	}
 }
 
@@ -564,30 +528,29 @@ KAKIKO
 #	@param	$Caption	
 #	@return	Ȃ
 #
-#	2010.08.12 windyakin 
-#	 -> Sambal̕\
-#
 #------------------------------------------------------------------------------------------------------------
 sub PrintIndexFoot
 {
-	my ($this, $Page, $Caption) = @_;
-	my ($SYS, $tblCol, $cgipath, $bbs, $ver, $tm, $samba);
+	my $this = shift;
+	my ($Page, $Caption) = @_;
 	
-	$SYS		= $this->{'SYS'};
-	$tblCol		= $this->{'SET'}->Get('BBS_MAKETHREAD_COLOR');
-	$cgipath	= $SYS->Get('CGIPATH');
-	$bbs		= $SYS->Get('BBS');
-	$ver		= $SYS->Get('VERSION');
-	$samba		= int ($this->{'SET'}->Get('BBS_SAMBATIME', '') eq '' ? $SYS->Get('DEFSAMBA') : $this->{'SET'}->Get('BBS_SAMBATIME'));
-	$tm			= time;
+	my $Sys = $this->{'SYS'};
+	my $Set = $this->{'SET'};
+	my $tblCol = $Set->Get('BBS_MAKETHREAD_COLOR');
+	my $cgipath = $Sys->Get('CGIPATH');
+	my $bbs = $Sys->Get('BBS');
+	my $ver = $Sys->Get('VERSION');
+	my $samba = int ($Set->Get('BBS_SAMBATIME', '') eq ''
+					? $Sys->Get('DEFSAMBA') : $Set->Get('BBS_SAMBATIME'));
+	my $tm = time;
 	
 	# Xbh쐬ʂʉʂŕ\
-	if ($this->{'SET'}->Equal('BBS_PASSWORD_CHECK', 'checked')) {
+	if ($Set->Equal('BBS_PASSWORD_CHECK', 'checked')) {
 		$Page->Print(<<FORM);
 <table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="$tblCol" align="center">
  <tr>
   <td>
-  <form method="POST" action="$cgipath/bbs.cgi" style="margin:1.2em 0;">
+  <form method="POST" action="$cgipath/bbs.cgi?guid=ON" style="margin:1.2em 0;">
   <input type="submit" value="VKXbh쐬ʂ"><br>
   <input type="hidden" name="bbs" value="$bbs">
   <input type="hidden" name="time" value="$tm">
@@ -600,7 +563,7 @@ FORM
 	# Xbh쐬tH[indexƓʂɕ\
 	else {
 		$Page->Print(<<FORM);
-<form method="POST" action="$cgipath/bbs.cgi">
+<form method="POST" action="$cgipath/bbs.cgi?guid=ON">
 <table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="#CCFFCC" style="margin-bottom:1.2em;" align="center">
  <tr>
   <td>&lrm;</td>
@@ -618,17 +581,15 @@ FORM
 	}
 	
 	# foot̕\
-	$Caption->Load($this->{'SYS'}, 'FOOT');
-	$Caption->Print($Page, $this->{'SET'});
+	$Caption->Load($Sys, 'FOOT');
+	$Caption->Print($Page, $Set);
 	
 	$Page->Print(<<FOOT);
 <div style="margin-top:1.2em;">
-<a href="http://validator.w3.org/check?uri=referer"><img src="$cgipath/datas/html.gif" alt="Valid HTML 4.01 Transitional" height="15" width="80" border="0"></a>
-<a href="http://0ch.mine.nu/">낿˂</a> <a href="http://zerochplus.sourceforge.jp/">vX</a>
+<a href="http://zerochplus.sourceforge.jp/">낿˂vX</a>
 BBS.CGI - $ver (Perl)
-@{[ $SYS->Get('BBQ') ? '+<a href="http://bbq.uso800.net/" target="_blank">BBQ</a>' : '' ]}
-@{[ $SYS->Get('BBX') ? '+BBX' : '' ]}
-@{[ $SYS->Get('SPAMCH') ? '+<a href="http://spam-champuru.livedoor.com/dnsbl/" target="_blank">XpՂ[</a>' : '' ]}
+@{[ $Sys->Get('BBQ') ? '+<a href="http://bbq.uso800.net/" target="_blank">BBQ</a>' : '' ]}
+@{[ $Sys->Get('BBX') ? '+BBX' : '' ]}
 +Samba24=$samba<br>
 y[Ŵ܂BB</div>
 
@@ -641,42 +602,41 @@ FOOT
 #
 #	index.html(Xbhvr[)
 #	-------------------------------------------------------------------------------------
-#	@param	$this	
-#	@param	$Page	
-#	@param	$oDat	
+#	@param	$Page		
+#	@param	$Dat		
+#	@param	$commands	
 #	@return	Ȃ
 #
 #------------------------------------------------------------------------------------------------------------
 sub PrintThreadPreviewOne
 {
-	my ($this, $Page, $oDat, $commands) = @_;
-	my ($pDat, $contNum, $start, $end, $i, $cgiPath, $bbs, $tm, $key);
+	my $this = shift;
+	my ($Page, $Dat, $commands) = @_;
+	
+	my $Sys = $this->{'SYS'};
 	
 	# O
-	$contNum	= $this->{'SET'}->Get('BBS_CONTENTS_NUMBER');
-	$cgiPath	= $this->{'SYS'}->Get('SERVER') . $this->{'SYS'}->Get('CGIPATH');
-	$bbs		= $this->{'SYS'}->Get('BBS');
-	$key		= $this->{'SYS'}->Get('KEY');
-	$tm			= time;
+	my $contNum = $this->{'SET'}->Get('BBS_CONTENTS_NUMBER');
+	my $cgiPath = $Sys->Get('SERVER') . $Sys->Get('CGIPATH');
+	my $bbs = $Sys->Get('BBS');
+	my $key = $Sys->Get('KEY');
+	my $tm = time;
 	
 	# \̐K
-	($start, $end) = $this->{'CONV'}->RegularDispNum(
-						$this->{'SYS'}, $oDat, 1, $contNum, $contNum);
-	if ($start == 1) {
-		$start++;
-	}
+	my ($start, $end) = $this->{'CONV'}->RegularDispNum($Sys, $Dat, 1, $contNum, $contNum);
+	$start++ if ($start == 1);
 	
 	# 1̕\
-	PrintResponse($this, $Page, $oDat, $commands, 1);
+	PrintResponse($this, $Page, $Dat, $commands, 1);
 	# c̕\
-	for ($i = $start ; $i <= $end ; $i++) {
-		PrintResponse($this, $Page, $oDat, $commands, $i);
+	for (my $i = $start; $i <= $end; $i++) {
+		PrintResponse($this, $Page, $Dat, $commands, $i);
 	}
 	
 	# ݃tH[̕\
 	$Page->Print(<<KAKIKO);
   </dl>
-  <form method="POST" action="$cgiPath/bbs.cgi">
+  <form method="POST" action="$cgiPath/bbs.cgi?guid=ON">
    <blockquote>
    <input type="hidden" name="bbs" value="$bbs">
    <input type="hidden" name="key" value="$key">
@@ -694,36 +654,38 @@ KAKIKO
 #
 #	index.html(X\)
 #	-------------------------------------------------------------------------------------
-#	@param	$this	
-#	@param	$Page	
-#	@param	$oDat	
-#	@param	$n		
+#	@param	$Page		
+#	@param	$Dat		
+#	@param	$commands	
+#	@param	$n			
 #	@return	Ȃ
 #
 #------------------------------------------------------------------------------------------------------------
 sub PrintResponse
 {
-	my ($this, $Page, $oDat, $commands, $n) = @_;
-	my ($oConv, @elem, $contLen, $contLine, $nameCol, $dispLine);
-	my ($pDat, $command);
+	my $this = shift;
+	my ($Page, $Dat, $commands, $n) = @_;
 	
-	$oConv		= $this->{'CONV'};
-	$pDat		= $oDat->Get($n - 1);
-	return if (! defined $pDat);
-	@elem		= split(/<>/, $$pDat);
-	$contLen	= length $elem[3];
-	$contLine	= $oConv->GetTextLine(\$elem[3]);
-	$nameCol	= $this->{'SET'}->Get('BBS_NAME_COLOR');
-	$dispLine	= $this->{'SET'}->Get('BBS_LINE_NUMBER');
+	my $Sys = $this->{'SYS'};
+	my $Conv = $this->{'CONV'};
+	
+	my $pdat = $Dat->Get($n - 1);
+	return if (!defined $pdat);
+	
+	my @elem = split(/<>/, $$pdat, -1);
+	my $contLen = length $elem[3];
+	my $contLine = $Conv->GetTextLine(\$elem[3]);
+	my $nameCol = $this->{'SET'}->Get('BBS_NAME_COLOR');
+	my $dispLine = $this->{'SET'}->Get('BBS_INDEX_LINE_NUMBER');
 	
 	# URLƈp̓K
-	$oConv->ConvertURL($this->{'SYS'}, $this->{'SET'}, 0, \$elem[3]);
-	$oConv->ConvertQuotation($this->{'SYS'}, \$elem[3], 0);
+	$Conv->ConvertURL($Sys, $this->{'SET'}, 0, \$elem[3]);
+	$Conv->ConvertQuotation($Sys, \$elem[3], 0);
 	
 	# g@\s
-	$this->{'SYS'}->Set('_DAT_', \@elem);
-	$this->{'SYS'}->Set('_NUM_', $n);
-	foreach $command (@$commands) {
+	$Sys->Set('_DAT_', \@elem);
+	$Sys->Set('_NUM_', $n);
+	foreach my $command (@$commands) {
 		$command->execute($this->{'SYS'}, undef, 8);
 	}
 	
@@ -744,14 +706,11 @@ sub PrintResponse
 	}
 	# \s𒴂ȗ\t
 	else {
-		my (@dispBuff, $path, $k);
-		
-		@dispBuff = split(/<br>|<BR>/, $elem[3]);
-		$path = $oConv->CreatePath($this->{'SYS'}, 0, $this->{'SYS'}->Get('BBS'),
-											$this->{'SYS'}->Get('KEY'), "${n}n");
+		my @dispBuff = split(/<br>/i, $elem[3]);
+		my $path = $Conv->CreatePath($Sys, 0, $Sys->Get('BBS'), $Sys->Get('KEY'), "${n}n");
 		
 		$Page->Print("F$elem[2]</dt>\n    <dd>");
-		for ($k = 0 ; $k < $dispLine ; $k++) {
+		for (my $k = 0; $k < $dispLine; $k++) {
 			$Page->Print("$dispBuff[$k]<br>");
 		}
 		$Page->Print("<font color=\"green\">iȗ܂EESĂǂނɂ");
