@@ -12,7 +12,7 @@
 package	MODULE;
 
 use strict;
-use warnings;
+#use warnings;
 
 #------------------------------------------------------------------------------------------------------------
 #
@@ -171,7 +171,7 @@ sub SetMenuList
 	$Base->SetMenu('O[vꗗ', "'bbs.cap','DISP','LIST'");
 	
 	# ǗO[vݒ茠̂
-	if ($pSys->{'SECINFO'}->IsAuthority($pSys->{'USER'}, 2, $bbs)) {
+	if ($pSys->{'SECINFO'}->IsAuthority($pSys->{'USER'}, $ZP::AUTH_CAPGROUP, $bbs)) {
 		$Base->SetMenu('O[vo^', "'bbs.cap','DISP','CREATE'");
 		$Base->SetMenu('O[vC|[g', "'bbs.cap','DISP','IMPORT'");
 	}
@@ -192,7 +192,7 @@ sub SetMenuList
 sub PrintGroupList
 {
 	my ($Page, $Sys, $Form) = @_;
-	my ($Group, $BBS, @groupSet, @user, $name, $expl, $id, $common, $isAuth, $n);
+	my ($Group, $BBS, @groupSet, @user, $name, $expl, $color, $id, $common, $isAuth, $n);
 	
 	$Sys->Set('_TITLE', 'CAP Group List');
 	
@@ -204,19 +204,21 @@ sub PrintGroupList
 	$Group->GetKeySet(\@groupSet);
 	
 	$Page->Print("<center><table border=0 cellspacing=2 width=100%>");
-	$Page->Print("<tr><td colspan=4><hr></td></tr>\n");
+	$Page->Print("<tr><td colspan=5><hr></td></tr>\n");
 	$Page->Print("<tr><td style=\"width:30\">@</td>");
 	$Page->Print("<td class=\"DetailTitle\" style=\"width:150\">Group Name</td>");
 	$Page->Print("<td class=\"DetailTitle\" style=\"width:200\">Subscription</td>");
+	$Page->Print("<td class=\"DetailTitle\" style=\"width:30\">Cap Color</td>");
 	$Page->Print("<td class=\"DetailTitle\" style=\"width:30\">Caps</td></tr>\n");
 	
 	# 擾
-	$isAuth = $Sys->Get('ADMIN')->{'SECINFO'}->IsAuthority($Sys->Get('ADMIN')->{'USER'}, 2, $Sys->Get('BBS'));
+	$isAuth = $Sys->Get('ADMIN')->{'SECINFO'}->IsAuthority($Sys->Get('ADMIN')->{'USER'}, $ZP::AUTH_CAPGROUP, $Sys->Get('BBS'));
 	
 	# O[vꗗo
 	foreach $id (@groupSet) {
 		$name = $Group->Get('NAME', $id);
 		$expl = $Group->Get('EXPL', $id);
+		$color = $Group->Get('COLOR', $id);
 		@user = split(/\,/, (defined ($_ = $Group->Get('CAPS', $id)) ? $_ : ''));
 		$n = @user;
 		
@@ -226,21 +228,21 @@ sub PrintGroupList
 		# ɂĕ\}
 		$Page->Print("<tr><td><input type=checkbox name=CAP_GROUPS value=$id></td>");
 		if ($isAuth) {
-			$Page->Print("<td><a href=$common>$name</a></td><td>$expl</td><td>$n</td></tr>\n");
+			$Page->Print("<td><a href=$common>$name</a></td><td>$expl</td><td>$color</td><td>$n</td></tr>\n");
 		}
 		else {
-			$Page->Print("<td>$name</td><td>$expl</td><td>$n</td></tr>\n");
+			$Page->Print("<td>$name</td><td>$expl</td><td>$color</td><td>$n</td></tr>\n");
 		}
 	}
 	$common = "onclick=\"DoSubmit('bbs.cap', 'DISP'";
 	
 	$Page->HTMLInput('hidden', 'SELECT_CAPGROUP', '');
-	$Page->Print("<tr><td colspan=4><hr></td></tr>\n");
+	$Page->Print("<tr><td colspan=5><hr></td></tr>\n");
 	
 	# ɂĕ\}
 	if ($isAuth) {
-		$Page->Print("<tr><td colspan=4 align=right>");
-		$Page->Print("<input type=button value=\"@폜@\" $common,'DELETE')\">");
+		$Page->Print("<tr><td colspan=5 align=left>");
+		$Page->Print("<input type=button value=\"@폜@\" $common,'DELETE')\" class=\"delete\">");
 		$Page->Print("</td></tr>\n");
 	}
 	$Page->Print("</table>");
@@ -261,7 +263,7 @@ sub PrintGroupSetting
 {
 	my ($Page, $Sys, $Form, $mode) = @_;
 	my ($Group, $User, @userSet, @authNum, $i, $num, $id);
-	my ($name, $expl, @auth, @user, $common);
+	my ($name, $expl, $color, @auth, @user, $common);
 	
 	$Sys->Set('_TITLE', 'CAP Group Edit')	if ($mode == 1);
 	$Sys->Set('_TITLE', 'CAP Group Create')	if ($mode == 0);
@@ -279,11 +281,12 @@ sub PrintGroupSetting
 	if ($mode) {
 		$name = $Group->Get('NAME', $Form->Get('SELECT_CAPGROUP'));
 		$expl = $Group->Get('EXPL', $Form->Get('SELECT_CAPGROUP'));
+		$color = $Group->Get('COLOR', $Form->Get('SELECT_CAPGROUP'));
 		@auth = split(/\,/, (defined ($_ = $Group->Get('AUTH', $Form->Get('SELECT_CAPGROUP'))) ? $_ : ''));
 		@user = split(/\,/, (defined ($_ = $Group->Get('CAPS', $Form->Get('SELECT_CAPGROUP'))) ? $_ : ''));
 		
 		# ԍ}bsOz쐬
-		for ($i = 0 ; $i < 19 ; $i++) {
+		for ($i = 0 ; $i < $ZP::CAP_MAXNUM ; $i++) {
 			$authNum[$i] = '';
 		}
 		foreach $num (@auth) {
@@ -294,7 +297,8 @@ sub PrintGroupSetting
 		$Form->Set('SELECT_CAPGROUP', '');
 		$name = '';
 		$expl = '';
-		for ($i = 0 ; $i < 19 ; $i++) {
+		$color = '';
+		for ($i = 0 ; $i < $ZP::CAP_MAXNUM ; $i++) {
 			$authNum[$i] = '';
 		}
 	}
@@ -308,6 +312,8 @@ sub PrintGroupSetting
 	$Page->Print("<input name=GROUPNAME_CAP type=text size=50 value=\"$name\"></td></tr>");
 	$Page->Print("<tr><td class=\"DetailTitle\"></td><td>");
 	$Page->Print("<input name=GROUPSUBS_CAP type=text size=50 value=\"$expl\"></td></tr>");
+	$Page->Print("<tr><td class=\"DetailTitle\">Lbv̐F(LŃftHg)</td><td>");
+	$Page->Print("<input name=GROUPCOLOR_CAP type=text size=50 value=\"$color\"></td></tr>");
 	$Page->Print("</table><br></td></tr>\n");
 	$Page->Print("<tr><td class=\"DetailTitle\" width=40%></td>");
 	$Page->Print("<td class=\"DetailTitle\">Lbv</td></tr><tr><td valign=top>");
@@ -326,12 +332,17 @@ sub PrintGroupSetting
 	$Page->Print("<input type=checkbox name=C_DUPLICATE $authNum[10] value=on>d݋K<br>");
 	$Page->Print("<input type=checkbox name=C_SHORTWRITE $authNum[11] value=on>ZԓeK<br>");
 	$Page->Print("<input type=checkbox name=C_READONLY $authNum[12] value=on>ǎpK<br>");
-	$Page->Print("<input type=checkbox name=C_IDDISP $authNum[13] value=on>ID\\K<br>");
-	$Page->Print("<input type=checkbox name=C_HOSTDISP $authNum[14] value=on>zXg\\K<br>");
+	$Page->Print("<input type=checkbox name=C_CUSTOMID $authNum[23] value=on>pID<br>");
+	$Page->Print("<input type=checkbox name=C_IDDISP $authNum[13] value=on>ID\\<br>");
+	$Page->Print("<input type=checkbox name=C_NOSLIP $authNum[22] value=on>[ʎq\\<br>");
+	$Page->Print("<input type=checkbox name=C_HOSTDISP $authNum[14] value=on>{zXg\\<br>");
 	$Page->Print("<input type=checkbox name=C_MOBILETHREAD $authNum[15] value=on>gт̃Xbh쐬<br>");
 	$Page->Print("<input type=checkbox name=C_FIXHANLDLE $authNum[16] value=on>Ren\\<br>");
 	$Page->Print("<input type=checkbox name=C_SAMBA $authNum[17] value=on>SambaK<br>");
 	$Page->Print("<input type=checkbox name=C_PROXY $authNum[18] value=on>vLVK<br>");
+	$Page->Print("<input type=checkbox name=C_JPHOST $authNum[19] value=on>COzXgK<br>");
+	$Page->Print("<input type=checkbox name=C_NGUSER $authNum[20] value=on>[U[K<br>");
+	$Page->Print("<input type=checkbox name=C_NGWORD $authNum[21] value=on>NG[hK<br>");
 	$Page->Print("</td>\n<td valign=top>");
 	
 	# [Uꗗ\
@@ -362,7 +373,7 @@ sub PrintGroupSetting
 	$Page->HTMLInput('hidden', 'SELECT_CAPGROUP', $Form->Get('SELECT_CAPGROUP'));
 	$Page->Print("</td></tr>");
 	$Page->Print("<tr><td colspan=2><hr></td></tr>");
-	$Page->Print("<tr><td colspan=2 align=right>");
+	$Page->Print("<tr><td colspan=2 align=left>");
 	$Page->Print("<input type=submit value=\"@ݒ@\" $common></td></tr>");
 	$Page->Print("</table><br>");
 }
@@ -414,8 +425,8 @@ sub PrintGroupDelete
 	$Page->Print("F폜O[vɖ߂Ƃ͂ł܂B</b><br>");
 	$Page->Print("F폜O[vɏĂLbvׂ͂ĖԂɂȂ܂B</td></tr>");
 	$Page->Print("<tr><td colspan=2><hr></td></tr>");
-	$Page->Print("<tr><td colspan=2 align=right><input type=button value=\"@폜@\" ");
-	$Page->Print("onclick=\"DoSubmit('bbs.cap','FUNC','DELETE')\"></td></tr>");
+	$Page->Print("<tr><td colspan=2 align=left><input type=button value=\"@폜@\" ");
+	$Page->Print("onclick=\"DoSubmit('bbs.cap','FUNC','DELETE')\" class=\"delete\"></td></tr>");
 	$Page->Print("</table>");
 }
 
@@ -454,7 +465,7 @@ sub PrintGroupImport
 	
 	$Page->Print("</select></td></tr>");
 	$Page->Print("<tr><td colspan=2><hr></td></tr>");
-	$Page->Print("<tr><td colspan=2 align=right><input type=button value=\"C|[g\"");
+	$Page->Print("<tr><td colspan=2 align=left><input type=button value=\"C|[g\"");
 	$Page->Print("onclick=\"DoSubmit('bbs.cap','FUNC','IMPORT');\"></td></tr></table>");
 }
 
@@ -476,14 +487,14 @@ sub FunctionGroupSetting
 {
 	my ($Sys, $Form, $mode, $pLog) = @_;
 	my ($Group, $User, @userSet, @authNum, @belongUser);
-	my ($name, $expl, $auth, $user, $i);
+	my ($name, $expl, $color, $auth, $user, $i);
 	
 	# `FbN
 	{
 		my $SEC = $Sys->Get('ADMIN')->{'SECINFO'};
-		my $chkID = $SEC->IsLogin($Form->Get('UserName'), $Form->Get('PassWord'));
+		my $chkID = $Sys->Get('ADMIN')->{'USER'};
 		
-		if (($SEC->IsAuthority($chkID, 1, $Sys->Get('BBS'))) == 0) {
+		if (($SEC->IsAuthority($chkID, $ZP::AUTH_CAPGROUP, $Sys->Get('BBS'))) == 0) {
 			return 1000;
 		}
 	}
@@ -505,6 +516,8 @@ sub FunctionGroupSetting
 	# {̐ݒ
 	$name = $Form->Get('GROUPNAME_CAP');
 	$expl = $Form->Get('GROUPSUBS_CAP');
+	$color = $Form->Get('GROUPCOLOR_CAP');
+	$color =~ s/[^\w\d\#]//ig;
 	
 	# ̐
 	$auth = '';
@@ -527,10 +540,15 @@ sub FunctionGroupSetting
 	$authNum[16]	= $Form->Equal('C_FIXHANLDLE', 'on') ? 1 : 0;
 	$authNum[17]	= $Form->Equal('C_SAMBA', 'on') ? 1 : 0;
 	$authNum[18]	= $Form->Equal('C_PROXY', 'on') ? 1 : 0;
+	$authNum[19]	= $Form->Equal('C_JPHOST', 'on') ? 1 : 0;
+	$authNum[20]	= $Form->Equal('C_NGUSER', 'on') ? 1 : 0;
+	$authNum[21]	= $Form->Equal('C_NGWORD', 'on') ? 1 : 0;
+	$authNum[22]	= $Form->Equal('C_NOSLIP', 'on') ? 1 : 0;
+	$authNum[23]	= $Form->Equal('C_CUSTOMID', 'on') ? 1 : 0;
 	
-	for ($i = 1 ; $i < 20 ; $i++) {
-		if ($authNum[$i - 1]){
-			$auth .= "$i,";
+	for ($i = 0 ; $i < $ZP::CAP_MAXNUM ; $i++) {
+		if ($authNum[$i]){
+			$auth .= ''.($i+1).',';
 		}
 	}
 	$auth = substr($auth, 0, length($auth) - 1);
@@ -544,11 +562,12 @@ sub FunctionGroupSetting
 		my $groupID = $Form->Get('SELECT_CAPGROUP');
 		$Group->Set($groupID, 'NAME', $name);
 		$Group->Set($groupID, 'EXPL', $expl);
+		$Group->Set($groupID, 'COLOR', $color);
 		$Group->Set($groupID, 'AUTH', $auth);
 		$Group->Set($groupID, 'CAPS', $user);
 	}
 	else {
-		$Group->Add($name, $expl, $auth, $user);
+		$Group->Add($name, $expl, $color, $auth, $user);
 	}
 	
 	# ݒۑ
@@ -560,6 +579,7 @@ sub FunctionGroupSetting
 		push @$pLog, 'ȉ̃LbvO[vo^܂B';
 		push @$pLog, "O[v́F$name";
 		push @$pLog, "F$expl";
+		push @$pLog, "FF$color";
 		push @$pLog, "F$auth";
 		push @$pLog, 'LbvF';
 		foreach	$id (@belongUser){
@@ -588,9 +608,9 @@ sub FunctionGroupDelete
 	# `FbN
 	{
 		my $SEC = $Sys->Get('ADMIN')->{'SECINFO'};
-		my $chkID = $SEC->IsLogin($Form->Get('UserName'), $Form->Get('PassWord'));
+		my $chkID = $Sys->Get('ADMIN')->{'USER'};
 		
-		if (($SEC->IsAuthority($chkID, 1, $Sys->Get('BBS'))) == 0) {
+		if (($SEC->IsAuthority($chkID, $ZP::AUTH_CAPGROUP, $Sys->Get('BBS'))) == 0) {
 			return 1000;
 		}
 	}
@@ -633,9 +653,9 @@ sub FunctionGroupImport
 	# `FbN
 	{
 		my $SEC	= $Sys->Get('ADMIN')->{'SECINFO'};
-		my $chkID	= $SEC->IsLogin($Form->Get('UserName'), $Form->Get('PassWord'));
+		my $chkID = $Sys->Get('ADMIN')->{'USER'};
 		
-		if (($SEC->IsAuthority($chkID, 1, $Sys->Get('BBS'))) == 0) {
+		if (($SEC->IsAuthority($chkID, $ZP::AUTH_CAPGROUP, $Sys->Get('BBS'))) == 0) {
 			return 1000;
 		}
 	}
@@ -645,20 +665,11 @@ sub FunctionGroupImport
 	$dst = $Sys->Get('BBSPATH') . '/' . $Sys->Get('BBS') . '/info/capgroups.cgi';
 	
 	# O[vݒRs[
-#	eval
-	{
-		EARENDIL::Copy($src, $dst);
-	};
+	EARENDIL::Copy($src, $dst);
 	
 	# Ȍo
-	if ($@ ne '') {
-		push @$pLog, $@;
-		return 9999;
-	}
-	else {
-		my $name = $BBS->Get('NAME', $Form->Get('IMPORT_BBS'));
-		push @$pLog, "u$nameṽLbvO[vݒC|[g܂B";
-	}
+	my $name = $BBS->Get('NAME', $Form->Get('IMPORT_BBS'));
+	push @$pLog, "u$nameṽLbvO[vݒC|[g܂B";
 	return 0;
 }
 
