@@ -9,7 +9,7 @@
 package	MODULE;
 
 use strict;
-use warnings;
+#use warnings;
 
 #------------------------------------------------------------------------------------------------------------
 #
@@ -183,12 +183,12 @@ sub SetMenuList
 	$Base->SetMenu('<hr>', '');
 	
 	# ǗO[vݒ茠̂
-	if ($pSys->{'SECINFO'}->IsAuthority($pSys->{'USER'}, 11, $bbs)) {
+	if ($pSys->{'SECINFO'}->IsAuthority($pSys->{'USER'}, $ZP::AUTH_ACCESUSER, $bbs)) {
 		$Base->SetMenu("K[U̕ҏW","'bbs.edit','DISP','USER'");
 		$bAuth = 1;
 	}
 	# ǗO[vݒ茠̂
-	if ($pSys->{'SECINFO'}->IsAuthority($pSys->{'USER'}, 10, $bbs)) {
+	if ($pSys->{'SECINFO'}->IsAuthority($pSys->{'USER'}, $ZP::AUTH_NGWORDS, $bbs)) {
 		$Base->SetMenu("NG[h̕ҏW","'bbs.edit','DISP','NGWORD'");
 		$bAuth = 1;
 	}
@@ -225,7 +225,7 @@ sub PrintHeaderEdit
 	$Setting->Load($SYS);
 	
 	# 擾
-	$isAuth = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, 14, $SYS->Get('BBS'));
+	$isAuth = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, $ZP::AUTH_BBSEDIT, $SYS->Get('BBS'));
 	
 	$Page->Print("<center><table border=0 cellspacing=2 width=100%>");
 	$Page->Print("<tr><td class=\"DetailTitle\" colspan=2>Preview</td></tr>");
@@ -263,9 +263,9 @@ sub PrintHeaderEdit
 	# ɂĕ\}
 	if ($isAuth) {
 		$common = "onclick=\"DoSubmit('bbs.edit'";
-		$Page->Print("<tr><td colspan=2 align=right>");
-		$Page->Print("<input type=button value=\"@mF@\" $common,'DISP','HEAD')\"> ");
-		$Page->Print("<input type=button value=\"@ύX@\" $common,'FUNC','HEAD')\">");
+		$Page->Print("<tr><td colspan=2 align=left>");
+		$Page->Print("<input type=button value=\"@ύX@\" $common,'FUNC','HEAD')\"> ");
+		$Page->Print("<input type=button value=\"@mF@\" $common,'DISP','HEAD')\">");
 		$Page->Print("</td></tr>\n");
 	}
 	$Page->Print("</table><br>");
@@ -293,7 +293,7 @@ sub PrintFooterEdit
 	$Foot->Load($SYS, 'FOOT');
 	
 	# 擾
-	$isAuth = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, 14, $SYS->Get('BBS'));
+	$isAuth = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, $ZP::AUTH_BBSEDIT, $SYS->Get('BBS'));
 	
 	$Page->Print("<table border=0 cellspacing=2 width=100%>");
 	$Page->Print("<tr><td class=\"DetailTitle\" colspan=2>Preview</td></tr>");
@@ -331,9 +331,9 @@ sub PrintFooterEdit
 	# ɂĕ\}
 	if ($isAuth) {
 		$common = "onclick=\"DoSubmit('bbs.edit'";
-		$Page->Print("<tr><td colspan=2 align=right>");
-		$Page->Print("<input type=button value=\"@mF@\" $common,'DISP','FOOT')\"> ");
-		$Page->Print("<input type=button value=\"@ύX@\" $common,'FUNC','FOOT')\">");
+		$Page->Print("<tr><td colspan=2 align=left>");
+		$Page->Print("<input type=button value=\"@ύX@\" $common,'FUNC','FOOT')\"> ");
+		$Page->Print("<input type=button value=\"@mF@\" $common,'DISP','FOOT')\">");
 		$Page->Print("</td></tr>\n");
 	}
 	$Page->Print("</table><br>");
@@ -364,7 +364,7 @@ sub PrintMETAEdit
 	$data = join '', @$pMeta;
 	
 	# 擾
-	$isAuth = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, 14, $SYS->Get('BBS'));
+	$isAuth = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, $ZP::AUTH_BBSEDIT, $SYS->Get('BBS'));
 	
 	$Page->Print("<center><table border=0 cellspacing=2 width=100%>");
 	$Page->Print("<tr><td colspan=2><hr></td></tr>\n");
@@ -383,7 +383,7 @@ sub PrintMETAEdit
 	# ɂĕ\}
 	if ($isAuth) {
 		$common = "onclick=\"DoSubmit('bbs.edit'";
-		$Page->Print("<tr><td colspan=2 align=right>");
+		$Page->Print("<tr><td colspan=2 align=left>");
 		$Page->Print("<input type=button value=\"@ύX@\" $common,'FUNC','META')\">");
 		$Page->Print("</td></tr>\n");
 	}
@@ -412,7 +412,7 @@ sub PrintValidUserEdit
 	$vUsers->Load($SYS);
 	
 	# 擾
-	$isAuth = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, 11, $SYS->Get('BBS'));
+	$isAuth = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, $ZP::AUTH_ACCESUSER, $SYS->Get('BBS'));
 	$pUsers = $vUsers->Get('USER');
 	
 	$kind[0] = $vUsers->Get('TYPE') eq 'disable' ? '' : 'selected';
@@ -422,11 +422,18 @@ sub PrintValidUserEdit
 	
 	$Page->Print("<center><table border=0 cellspacing=2 width=100%>");
 	$Page->Print("<tr><td colspan=2><hr></td></tr>\n");
-	$Page->Print("<tr><td class=\"DetailTitle\">ΏۃzXgꗗ</td><td>");
+	$Page->Print("<tr><td class=\"DetailTitle\">ΏۃzXgE<br>[ʎqꗗ</td><td>");
 	$Page->Print("<textarea name=VALID_USERS rows=10 cols=70 wrap=off>");
 	
+	my $sanitize = sub {
+		$_ = shift;
+		s/&/&amp;/g;
+		s/</&lt;/g;
+		s/>/&gt;/g;
+		return $_;
+	};
 	foreach (@$pUsers) {
-		$Page->Print("$_\n");
+		$Page->Print(&$sanitize($_)."\n");
 	}
 	
 	$Page->Print("</textarea></td></tr>\n");
@@ -447,7 +454,7 @@ sub PrintValidUserEdit
 	# ɂĕ\}
 	if ($isAuth) {
 		$common = "onclick=\"DoSubmit('bbs.edit'";
-		$Page->Print("<tr><td colspan=2 align=right>");
+		$Page->Print("<tr><td colspan=2 align=left>");
 		$Page->Print("<input type=button value=\"@ݒ@\" $common,'FUNC','USER')\">");
 		$Page->Print("</td></tr>\n");
 	}
@@ -467,7 +474,7 @@ sub PrintValidUserEdit
 sub PrintNGWordsEdit
 {
 	my ($Page, $SYS, $Form) = @_;
-	my ($Words, $pWords, $common, $isAuth, @kind);
+	my ($Words, $pWords, $pRepls, $common, $isAuth, @kind);
 	
 	$SYS->Set('_TITLE', 'BBS NG Words Edit');
 	
@@ -476,8 +483,9 @@ sub PrintNGWordsEdit
 	$Words->Load($SYS);
 	
 	# 擾
-	$isAuth = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, 10, $SYS->Get('BBS'));
+	$isAuth = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, $ZP::AUTH_NGWORDS, $SYS->Get('BBS'));
 	$pWords = $Words->Get('NGWORD');
+	$pRepls = $Words->Get('REPLACE');
 	
 	$kind[0] = $Words->Get('METHOD', '') eq 'disable' ? 'selected' : '';
 	$kind[1] = $Words->Get('METHOD', '') eq 'host' ? 'selected' : '';
@@ -487,11 +495,21 @@ sub PrintNGWordsEdit
 	
 	$Page->Print("<center><table border=0 cellspacing=2 width=100%>");
 	$Page->Print("<tr><td colspan=2><hr></td></tr>\n");
-	$Page->Print("<tr><td class=\"DetailTitle\">NG[hꗗ</td><td>");
+	$Page->Print("<tr><td class=\"DetailTitle\">NG[hꗗ");
+	$Page->Print("<br><br>NG[h<br>NG[h&lt;&gt;u</td><td>");
 	$Page->Print("<textarea name=NG_WORDS rows=10 cols=70 wrap=off>");
 	
-	foreach (@$pWords) {
-		$Page->Print("$_\n");
+	my $sanitize = sub {
+		$_ = shift;
+		s/&/&amp;/g;
+		s/</&lt;/g;
+		s/>/&gt;/g;
+		return $_;
+	};
+	foreach my $i (0 .. $#$pWords) {
+		$Page->Print(&$sanitize($pWords->[$i]));
+		$Page->Print(&$sanitize('<>'.$pRepls->[$i])) if (defined $pRepls->[$i]);
+		$Page->Print("\n");
 	}
 	
 	$Page->Print("</textarea></td></tr>\n");
@@ -503,14 +521,14 @@ sub PrintNGWordsEdit
 	$Page->Print("<option value=delete $kind[2]>NG[h폜</option>");
 	$Page->Print("<option value=substitute $kind[3]>NG[hu</option>");
 	$Page->Print("</select></td></tr>\n");
-	$Page->Print("<tr><td class=\"DetailTitle\">NG[hu</td><td>");
+	$Page->Print("<tr><td class=\"DetailTitle\">ftHgu</td><td>");
 	$Page->Print("<input type=text name=NG_SUBSTITUTE value=\"$kind[4]\" size=60></td></tr>\n");
 	$Page->Print("<tr><td colspan=2><hr></td></tr>\n");
 	
 	# ɂĕ\}
 	if ($isAuth) {
 		$common = "onclick=\"DoSubmit('bbs.edit'";
-		$Page->Print("<tr><td colspan=2 align=right>");
+		$Page->Print("<tr><td colspan=2 align=left>");
 		$Page->Print("<input type=button value=\"@ݒ@\" $common,'FUNC','NGWORD')\">");
 		$Page->Print("</td></tr>\n");
 	}
@@ -550,13 +568,13 @@ sub PrintLastEdit
 		$path = $SYS->Get('BBSPATH') . '/' . $SYS->Get('BBS') . '/1000.txt';
 		$isLast = 0;
 		
-		if (-e $path) {
-			open LAST, $path;
-			while(<LAST>) {
+		if (open(my $f_last, '<', $path)) {
+			flock($f_last, 2);
+			while(<$f_last>) {
 				$data = $_;
 				last;
 			}
-			close LAST;
+			close($f_last);
 			chomp $data;
 			$isLast = 1;
 		}
@@ -585,7 +603,7 @@ sub PrintLastEdit
 	}
 	
 	# 擾
-	$isAuth = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, 14, $SYS->Get('BBS'));
+	$isAuth = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, $ZP::AUTH_BBSEDIT, $SYS->Get('BBS'));
 	
 	$Page->Print("<center><table border=0 cellspacing=2 width=100%>");
 	$Page->Print("<tr><td class=\"DetailTitle\" colspan=2>Preview</td></tr>");
@@ -623,9 +641,9 @@ sub PrintLastEdit
 	# ɂĕ\}
 	if ($isAuth) {
 		$common = "onclick=\"DoSubmit('bbs.edit'";
-		$Page->Print("<tr><td colspan=2 align=right>");
-		$Page->Print("<input type=button value=\"@mF@\" $common,'DISP','LAST')\"> ");
-		$Page->Print("<input type=button value=\"@ύX@\" $common,'FUNC','LAST')\">");
+		$Page->Print("<tr><td colspan=2 align=left>");
+		$Page->Print("<input type=button value=\"@ύX@\" $common,'FUNC','LAST')\"> ");
+		$Page->Print("<input type=button value=\"@mF@\" $common,'DISP','LAST')\">");
 		$Page->Print("</td></tr>\n");
 	}
 	$Page->Print("</table><br>");
@@ -650,9 +668,9 @@ sub FunctionTextEdit
 	# `FbN
 	{
 		my $SEC	= $Sys->Get('ADMIN')->{'SECINFO'};
-		my $chkID	= $SEC->IsLogin($Form->Get('UserName'), $Form->Get('PassWord'));
+		my $chkID = $Sys->Get('ADMIN')->{'USER'};
 		
-		if (($SEC->IsAuthority($chkID, 14, $Sys->Get('BBS'))) == 0) {
+		if (($SEC->IsAuthority($chkID, $ZP::AUTH_BBSEDIT, $Sys->Get('BBS'))) == 0) {
 			return 1000;
 		}
 	}
@@ -705,9 +723,9 @@ sub FunctionValidUserEdit
 	# `FbN
 	{
 		my $SEC	= $Sys->Get('ADMIN')->{'SECINFO'};
-		my $chkID	= $SEC->IsLogin($Form->Get('UserName'), $Form->Get('PassWord'));
+		my $chkID = $Sys->Get('ADMIN')->{'USER'};
 		
-		if (($SEC->IsAuthority($chkID, 11, $Sys->Get('BBS'))) == 0) {
+		if (($SEC->IsAuthority($chkID, $ZP::AUTH_ACCESUSER, $Sys->Get('BBS'))) == 0) {
 			return 1000;
 		}
 	}
@@ -720,10 +738,18 @@ sub FunctionValidUserEdit
 	$vUsers->Set('METHOD', $Form->Get('VALID_METHOD'));
 	
 	$vUsers->Clear();
+	
+	my $sanitize = sub {
+		$_ = shift;
+		s/&/&amp;/g;
+		s/</&lt;/g;
+		s/>/&gt;/g;
+		return $_;
+	};
 	push @$pLog, 'ȉ̃[Uw';
 	foreach (@validUsers) {
 		$vUsers->Add($_);
-		push @$pLog, '@@' . $_;
+		push @$pLog, '@@' . &$sanitize($_);
 	}
 	push @$pLog, 'w胆[UʁF' . $Form->Get('VALID_TYPE');
 	push @$pLog, 'w胆[UuF' . $Form->Get('VALID_METHOD');
@@ -751,9 +777,9 @@ sub FunctionNGWordEdit
 	# `FbN
 	{
 		my $SEC = $Sys->Get('ADMIN')->{'SECINFO'};
-		my $chkID = $SEC->IsLogin($Form->Get('UserName'), $Form->Get('PassWord'));
+		my $chkID = $Sys->Get('ADMIN')->{'USER'};
 		
-		if (($SEC->IsAuthority($chkID, 10, $Sys->Get('BBS'))) == 0) {
+		if (($SEC->IsAuthority($chkID, $ZP::AUTH_NGWORDS, $Sys->Get('BBS'))) == 0) {
 			return 1000;
 		}
 	}
@@ -766,10 +792,20 @@ sub FunctionNGWordEdit
 	$Words->Set('SUBSTITUTE', $Form->Get('NG_SUBSTITUTE'));
 	
 	$Words->Clear();
+	
+	my $sanitize = sub {
+		$_ = shift;
+		s/&/&amp;/g;
+		s/</&lt;/g;
+		s/>/&gt;/g;
+		return $_;
+	};
 	push @$pLog, 'NG[hƂĈȉݒ';
 	foreach (@ngWords) {
-		$Words->Add($_);
-		push @$pLog, '@@' . $_;
+		my ($word, $repl) = split(/<>/, $_, -1);
+		if ($Words->Add($word, $repl)) {
+			push @$pLog, '@@'.&$sanitize($word).(defined $repl ? &$sanitize("<>$repl") : '');
+		}
 	}
 	push @$pLog, 'NG[huF' . $Form->Get('NG_METHOD');
 	
@@ -796,9 +832,9 @@ sub FunctionLastEdit
 	# `FbN
 	{
 		my $SEC	= $Sys->Get('ADMIN')->{'SECINFO'};
-		my $chkID	= $SEC->IsLogin($Form->Get('UserName'), $Form->Get('PassWord'));
+		my $chkID = $Sys->Get('ADMIN')->{'USER'};
 		
-		if (($SEC->IsAuthority($chkID, 14, $Sys->Get('BBS'))) == 0) {
+		if (($SEC->IsAuthority($chkID, $ZP::AUTH_BBSEDIT, $Sys->Get('BBS'))) == 0) {
 			return 1000;
 		}
 	}
@@ -829,18 +865,16 @@ sub FunctionLastEdit
 		$mail =~ s/<>/&lt;&gt;/g;
 		$date =~ s/<>/&lt;&gt;/g;
 		$cont =~ s/<>/&lt;&gt;/g;
-#		eval
-		{
-			open LAST, "> $lastPath";
-			flock LAST, 2;
-			binmode LAST;
-			print LAST "$name<>$mail<>$date<> $cont <>\n";
-			close LAST;
-		};
-		if ($@ ne ''){
-			push @$pLog, $@;
-			return 9999;
+		
+		if (open(my $f_last, (-f $lastPath ? '+<' : '>'), $lastPath)) {
+			flock($f_last, 2);
+			seek($f_last, 0, 0);
+			binmode($f_last);
+			print $f_last "$name<>$mail<>$date<> $cont <>\n";
+			truncate($f_last, tell($f_last));
+			close($f_last);
 		}
+		
 		push @$pLog, '1000.txtݒ肵܂B';
 	}
 	
