@@ -9,7 +9,7 @@
 package	MODULE;
 
 use strict;
-use warnings;
+#use warnings;
 
 #------------------------------------------------------------------------------------------------------------
 #
@@ -204,25 +204,26 @@ sub PrintThreadList
 	$common		= "DoSubmit('bbs.pool','DISP','LIST');";
 	
 	$Page->Print("<center><table border=0 cellspacing=2 width=100%>");
-	$Page->Print("<tr><td colspan=2><b><a href=\"javascript:SetOption('DISPST', " . ($dispSt - $dispNum));
+	$Page->Print("<tr><td colspan=3><b><a href=\"javascript:SetOption('DISPST', " . ($dispSt - $dispNum));
 	$Page->Print(");$common\">&lt;&lt; PREV</a> | <a href=\"javascript:SetOption('DISPST', ");
 	$Page->Print("" . ($dispSt + $dispNum) . ");$common\">NEXT &gt;&gt;</a></b>");
 	$Page->Print("</td><td colspan=2 align=right>");
 	$Page->Print("\\<input type=text name=DISPNUM size=4 value=$dispNum>");
 	$Page->Print("<input type=button value=\"@\\@\" onclick=\"$common\"></td></tr>\n");
-	$Page->Print("<tr><td colspan=4><hr></td></tr>\n");
-	$Page->Print("<tr><td style=\"width:30\">@</td>");
-	$Page->Print("<td class=\"DetailTitle\" style=\"width:250\">Thread Title</td>");
-	$Page->Print("<td class=\"DetailTitle\" style=\"width:100\">Thread Key</td>");
-	$Page->Print("<td class=\"DetailTitle\" style=\"width:50\">Res</td></tr>\n");
+	$Page->Print("<tr><td colspan=5><hr></td></tr>\n");
+	$Page->Print("<tr><th style=\"width:30px\">@</th>");
+	$Page->Print("<td class=\"DetailTitle\" style=\"width:250px\">Thread Title</td>");
+	$Page->Print("<td class=\"DetailTitle\" style=\"width:30px\">Thread Key</td>");
+	$Page->Print("<td class=\"DetailTitle\" style=\"width:20px\">Res</td>");
+	$Page->Print("<td class=\"DetailTitle\" style=\"width:100px\">Attribute</td></tr>\n");
 	
 	# 擾
 	my ($isRepare, $isDelete, $isUpdate, $isCreate);
 	
-	$isRepare = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, 4, $SYS->Get('BBS'));
-	$isDelete = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, 5, $SYS->Get('BBS'));
-	$isUpdate = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, 6, $SYS->Get('BBS'));
-	$isCreate = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, 7, $SYS->Get('BBS'));
+	$isRepare = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, $ZP::AUTH_THREADPOOL, $SYS->Get('BBS'));
+	$isDelete = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, $ZP::AUTH_TREADDELETE, $SYS->Get('BBS'));
+	$isUpdate = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, $ZP::AUTH_THREADINFO, $SYS->Get('BBS'));
+	$isCreate = $SYS->Get('ADMIN')->{'SECINFO'}->IsAuthority($SYS->Get('ADMIN')->{'USER'}, $ZP::AUTH_KAKOCREATE, $SYS->Get('BBS'));
 	
 	for ($i = $dispSt ; $i < $dispEd ; $i++) {
 		$id		= $threadSet[$i];
@@ -231,18 +232,23 @@ sub PrintThreadList
 		
 		$Page->Print("<tr><td><input type=checkbox name=THREADS value=$id></td>");
 		$Page->Print("<td>$subj</td>");
-		$Page->Print("<td align=center>$id</td><td align=center>$res</td></tr>\n");
+		$Page->Print("<td align=center>$id</td><td align=center>$res</td>");
+		
+		my @attrstr = ();
+		#push @attrstr, '~' if ($Threads->GetAttr($id, 'stop'));
+		push @attrstr, '' if ($Threads->GetAttr($id, 'float'));
+		$Page->Print("<td>@attrstr</td></tr>\n");
 	}
 	$common		= "onclick=\"DoSubmit('bbs.pool','DISP'";
 	$common2	= "onclick=\"DoSubmit('bbs.pool','FUNC'";
 	
-	$Page->Print("<tr><td colspan=4><hr></td></tr>\n");
-	$Page->Print("<tr><td colspan=4 align=right>");
+	$Page->Print("<tr><td colspan=5><hr></td></tr>\n");
+	$Page->Print("<tr><td colspan=5 align=left>");
 	$Page->Print("<input type=button value=\"@XV@\" $common2,'UPDATE')\"> ")	if ($isUpdate);
 	$Page->Print("<input type=button value=\" SXV \" $common2,'UPDATEALL')\"> ")	if ($isUpdate);
 	$Page->Print("<input type=button value=\"@A@\" $common,'REPARE')\"> ")		if ($isRepare);
-	$Page->Print("<input type=button value=\"@폜@\" $common,'DELETE')\"> ")		if ($isDelete);
 	$Page->Print("<input type=button value=\"ߋO\" $common2,'CREATE')\"> ")	if ($isCreate);
+	$Page->Print("<input type=button value=\"@폜@\" $common,'DELETE')\" class=\"delete\"> ")		if ($isDelete);
 	$Page->Print("</td></tr>\n");
 	$Page->Print("</table><br>");
 	
@@ -291,10 +297,7 @@ sub PrintThreadRepare
 	$common = "DoSubmit('bbs.pool','FUNC','REPARE')";
 	
 	$Page->Print("<tr><td colspan=3><hr></td></tr>\n");
-	$Page->Print("<tr><td bgcolor=yellow colspan=3><b><font color=red>");
-	$Page->Print("FDATXbh[DATXbh]ʂŕAł܂B</b><br>");
-	$Page->Print("<tr><td colspan=3><hr></td></tr>\n");
-	$Page->Print("<tr><td colspan=3 align=right>");
+	$Page->Print("<tr><td colspan=3 align=left>");
 	$Page->Print("<input type=button value=\"@A@\" onclick=\"$common\"> ");
 	$Page->Print("</td></tr>\n");
 	$Page->Print("</table><br>");
@@ -345,8 +348,8 @@ sub PrintThreadDelete
 	$Page->Print("<tr><td bgcolor=yellow colspan=3><b><font color=red>");
 	$Page->Print("F폜Xbhɖ߂Ƃ͂ł܂B</b><br>");
 	$Page->Print("<tr><td colspan=3><hr></td></tr>\n");
-	$Page->Print("<tr><td colspan=3 align=right>");
-	$Page->Print("<input type=button value=\"@폜@\" onclick=\"$common\"> ");
+	$Page->Print("<tr><td colspan=3 align=left>");
+	$Page->Print("<input type=button value=\"@폜@\" onclick=\"$common\" class=\"delete\"> ");
 	$Page->Print("</td></tr>\n");
 	$Page->Print("</table><br>");
 }
@@ -369,9 +372,9 @@ sub FunctionThreadRepare
 	# `FbN
 	{
 		my $SEC	= $Sys->Get('ADMIN')->{'SECINFO'};
-		my $chkID	= $SEC->IsLogin($Form->Get('UserName'), $Form->Get('PassWord'));
+		my $chkID = $Sys->Get('ADMIN')->{'USER'};
 		
-		if (($SEC->IsAuthority($chkID, 4, $Sys->Get('BBS'))) == 0) {
+		if (($SEC->IsAuthority($chkID, $ZP::AUTH_THREADPOOL, $Sys->Get('BBS'))) == 0) {
 			return 1000;
 		}
 	}
@@ -419,9 +422,9 @@ sub FunctionThreadDelete
 	# `FbN
 	{
 		my $SEC	= $Sys->Get('ADMIN')->{'SECINFO'};
-		my $chkID	= $SEC->IsLogin($Form->Get('UserName'), $Form->Get('PassWord'));
+		my $chkID = $Sys->Get('ADMIN')->{'USER'};
 		
-		if (($SEC->IsAuthority($chkID, 5, $Sys->Get('BBS'))) == 0) {
+		if (($SEC->IsAuthority($chkID, $ZP::AUTH_TREADDELETE, $Sys->Get('BBS'))) == 0) {
 			return 1000;
 		}
 	}
@@ -432,13 +435,16 @@ sub FunctionThreadDelete
 	
 	@threadList = $Form->GetAtArray('THREADS');
 	$bbs		= $Sys->Get('BBS');
-	$path		= $Sys->Get('BBSPATH') . "/$bbs/pool";
+	$path		= $Sys->Get('BBSPATH') . "/$bbs";
 	
 	foreach $id (@threadList) {
 		next if (! defined $Pools->Get('SUBJECT', $id));
 		push @$pLog, 'POOLXbhu' . $Pools->Get('SUBJECT', $id) . 'v폜';
 		$Pools->Delete($id);
-		unlink "$path/$id.cgi";
+		$Pools->DeleteAttr($id);
+		unlink "$path/pool/$id.cgi";
+		unlink "$path/log/$id.cgi";
+		unlink "$path/log/del_$id.cgi";
 	}
 	$Pools->Save($Sys);
 	
@@ -463,9 +469,9 @@ sub FunctionUpdateSubject
 	# `FbN
 	{
 		my $SEC	= $Sys->Get('ADMIN')->{'SECINFO'};
-		my $chkID	= $SEC->IsLogin($Form->Get('UserName'), $Form->Get('PassWord'));
+		my $chkID = $Sys->Get('ADMIN')->{'USER'};
 		
-		if (($SEC->IsAuthority($chkID, 6, $Sys->Get('BBS'))) == 0) {
+		if (($SEC->IsAuthority($chkID, $ZP::AUTH_THREADINFO, $Sys->Get('BBS'))) == 0) {
 			return 1000;
 		}
 	}
@@ -499,9 +505,9 @@ sub FunctionUpdateSubjectAll
 	# `FbN
 	{
 		my $SEC	= $Sys->Get('ADMIN')->{'SECINFO'};
-		my $chkID	= $SEC->IsLogin($Form->Get('UserName'), $Form->Get('PassWord'));
+		my $chkID = $Sys->Get('ADMIN')->{'USER'};
 		
-		if (($SEC->IsAuthority($chkID, 6, $Sys->Get('BBS'))) == 0) {
+		if (($SEC->IsAuthority($chkID, $ZP::AUTH_THREADINFO, $Sys->Get('BBS'))) == 0) {
 			return 1000;
 		}
 	}
@@ -536,9 +542,9 @@ sub FunctionCreateLogs
 	# `FbN
 	{
 		my $SEC	= $Sys->Get('ADMIN')->{'SECINFO'};
-		my $chkID	= $SEC->IsLogin($Form->Get('UserName'), $Form->Get('PassWord'));
+		my $chkID = $Sys->Get('ADMIN')->{'USER'};
 		
-		if (($SEC->IsAuthority($chkID, 7, $Sys->Get('BBS'))) == 0) {
+		if (($SEC->IsAuthority($chkID, $ZP::AUTH_KAKOCREATE, $Sys->Get('BBS'))) == 0) {
 			return 1000;
 		}
 	}
@@ -564,33 +570,27 @@ sub FunctionCreateLogs
 	$basePath = $Sys->Get('BBSPATH') . '/' . $Sys->Get('BBS') . '/pool';
 	$bCreate = 0;
 	
-#	eval
-	{
-		foreach $key (@poolSet) {
-			if ($Dat->Load($Sys,"$basePath/$key.cgi", 1)) {
-				if (CreateKAKOLog($Page, $Sys, $Set, $Banner, $Dat, $Conv, $key)) {
-					if ($Logs->Get('KEY', $key, '') eq '') {
-						$Logs->Add($key, $Dat->GetSubject(), time, '/' . substr($key, 0, 4) . '/' . substr($key, 0, 5));
-					}
-					else {
-						$Logs->($key, 'SUBJECT', $Dat->GetSubject());
-						$Logs->($key, 'DATE', time);
-						$Logs->($key, 'PATH', '/' . substr($key, 0, 4) . '/' . substr($key, 0, 5));
-					}
-					$bCreate = 1;
-					push @$pLog, "$keyFߋO";
+	foreach $key (@poolSet) {
+		if ($Dat->Load($Sys,"$basePath/$key.cgi", 1)) {
+			if (CreateKAKOLog($Page, $Sys, $Set, $Banner, $Dat, $Conv, $key)) {
+				if ($Logs->Get('KEY', $key, '') eq '') {
+					$Logs->Add($key, $Dat->GetSubject(), time, '/' . substr($key, 0, 4) . '/' . substr($key, 0, 5));
 				}
+				else {
+					$Logs->($key, 'SUBJECT', $Dat->GetSubject());
+					$Logs->($key, 'DATE', time);
+					$Logs->($key, 'PATH', '/' . substr($key, 0, 4) . '/' . substr($key, 0, 5));
+				}
+				$bCreate = 1;
+				push @$pLog, "$keyFߋO";
 			}
-			if (! $bCreate){
-				push @$pLog, "$keyFߋOs";
-			}
-			$bCreate = 0;
 		}
-	};
-	if ($@ ne '') {
-		push @$pLog, $@;
-		return 9999;
+		if (! $bCreate){
+			push @$pLog, "$keyFߋOs";
+		}
+		$bCreate = 0;
 	}
+	
 	$Logs->Save($Sys);
 	
 	return 0;
@@ -636,13 +636,11 @@ sub CreateKAKOLog
 	$color[4]	= $Set->Get('BBS_ALINK_COLOR');
 	$color[5]	= $Set->Get('BBS_VLINK_COLOR');
 	
-#	eval
-	{
-		require './module/earendil.pl';
-		
-		$Page->Clear();
-		
-		$Page->Print(<<HTML);
+	require './module/earendil.pl';
+	
+	$Page->Clear();
+	
+	$Page->Print(<<HTML);
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html lang="ja">
 <head>
@@ -650,10 +648,10 @@ sub CreateKAKOLog
  <meta http-equiv="Content-Type" content="text/html;charset=Shift_JIS">
 
 HTML
-		
-		$Caption->Print($Page, undef);
-		
-		$Page->Print(<<HTML);
+	
+	$Caption->Print($Page, undef);
+	
+	$Page->Print(<<HTML);
  <title>$title</title>
 
 </head>
@@ -662,10 +660,10 @@ HTML
 
 HTML
 
-		# mo
-		$Banner->Print($Page, 100, 2, 0) if ($Sys->Get('BANNER'));
-		
-		$Page->Print(<<HTML);
+	# mo
+	$Banner->Print($Page, 100, 2, 0) if ($Sys->Get('BANNER'));
+	
+	$Page->Print(<<HTML);
 <div style="margin:0px;">
  <a href="http://ofuda.cc/"><img width="400" height="15" border="0" src="http://e.ofuda.cc/disp/$account/00813400.gif" alt="ANZXJE^[ofuda.ccuSEJEgvv"></a>
  <div style="margin-top:1em;">
@@ -679,17 +677,17 @@ HTML
 <h1 style="color:red;font-size:larger;font-weight:normal;margin:-.5em 0 0;">$title</h1>
 
 HTML
-		
-		$Page->Print("<dl>\n");
-		
-		# X̏o
-		for ($i = 0 ; $i < $Dat->Size() ; $i++) {
-			PrintResponse($Sys, $Page, $Dat->Get($i), $i + 1, $Conv, $Set);
-		}
-		
-		$Page->Print("</dl>\n");
-		
-		$Page->Print(<<HTML);
+	
+	$Page->Print("<dl>\n");
+	
+	# X̏o
+	for ($i = 0 ; $i < $Dat->Size() ; $i++) {
+		PrintResponse($Sys, $Page, $Dat->Get($i), $i + 1, $Conv, $Set);
+	}
+	
+	$Page->Print("</dl>\n");
+	
+	$Page->Print(<<HTML);
 
 <hr>
 
@@ -698,25 +696,20 @@ HTML
  <a href="$board/kako/">ߋOqɂ֖߂遡</a>
 </div>
 <div align="right">
-<a href="http://validator.w3.org/check?uri=referer"><img src="$cgipath/datas/html.gif" alt="Valid HTML 4.01 Transitional" height="15" width="80" border="0"></a>
 $var
 </div>
 
 
 HTML
-		
-		$Page->Print("</body>\n</html>\n");
-		$Dat->Close();
-		
-		# ߋȌo
-		EARENDIL::CreateFolderHierarchy($logDir);
-		EARENDIL::Copy($datPath, "$logDir/$key.dat");
-		$Page->Flush(1, $Sys->Get('PM-TXT'), $logPath);
-	};
-	if ($@ ne '') {
-		$Dat->Close();
-		return 0;
-	}
+	
+	$Page->Print("</body>\n</html>\n");
+	$Dat->Close();
+	
+	# ߋȌo
+	EARENDIL::CreateFolderHierarchy($logDir, $Sys->Get('PM-BDIR'));
+	EARENDIL::Copy($datPath, "$logDir/$key.dat");
+	$Page->Flush(1, $Sys->Get('PM-TXT'), $logPath);
+	
 	return 1;
 }
 
